@@ -3,7 +3,7 @@ package MVC::Neaf::Request;
 use strict;
 use warnings;
 
-our $VERSION = '0.2603_03';
+our $VERSION = '0.2701_02';
 
 =head1 NAME
 
@@ -50,12 +50,11 @@ use HTTP::Headers::Fast;
 use Time::HiRes ();
 use Sys::Hostname ();
 use Digest::MD5 qw(md5);
-use Scalar::Util qw(reftype);
 
 use MVC::Neaf::Util qw( JSON http_date run_all_nodie canonize_path encode_b64 );
 use MVC::Neaf::Upload;
 use MVC::Neaf::Exception;
-use MVC::Neaf::Route::Null;
+use MVC::Neaf::Route::PreRoute;
 
 our %allow_helper;
 
@@ -220,7 +219,9 @@ instead.
 
 sub route {
     my $self = shift;
-    return $self->{route} ||= MVC::Neaf::Route::Null->new;
+    return $self->{route} ||= MVC::Neaf::Route::PreRoute->new(
+        method => 'GET',
+    );
 };
 
 =head2 set_path()
@@ -1106,7 +1107,7 @@ sub header_in {
     # TODO 0.30 deprecate w/o regex
     if ($regex) {
         $regex = qr/^$regex$/
-            unless ref $regex and reftype $regex eq 'REGEXP';
+            unless ref $regex and ref $regex eq 'Regexp';
         $_ =~ $regex or die 422 # TODO 0.30 configurable
             for @list;
     };
@@ -2096,7 +2097,7 @@ sub get_default {
 
 This module is part of L<MVC::Neaf> suite.
 
-Copyright 2016-2018 Konstantin S. Uvarin C<khedin@cpan.org>.
+Copyright 2016-2019 Konstantin S. Uvarin C<khedin@cpan.org>.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
