@@ -2,7 +2,7 @@ package MVC::Neaf::Route::Main;
 
 use strict;
 use warnings;
-our $VERSION = '0.2603_03';
+our $VERSION = '0.2701_02';
 
 =head1 NAME
 
@@ -33,8 +33,10 @@ use MVC::Neaf::Util::Container;
 use MVC::Neaf::Request::PSGI;
 use MVC::Neaf::Route::PreRoute;
 
+# TODO 0.30 remove
 sub _one_and_true {
     my $self = shift;
+    return $self if ref $self;
 
     my $method = [caller 1]->[3];
     $method =~ s/.*:://;
@@ -50,33 +52,23 @@ sub _one_and_true {
 
 =head2 new()
 
-    new( %options )
+    new( )
 
 This is also called by C<MVC::Neaf-E<gt>new>,
 in case one wants to instantiate a Neaf application object
 instead of using the default L<MVC::Neaf/neaf>.
 
-Options may include:
-
-=over
-
-=item force_view - use that view instead of anything specified by controller.
-See L</load_view> for details about how view is declared.
-Useful for debugging.
-
-=back
+A hash of %options may be added in the future, but isn't supported currently.
 
 =cut
 
 sub new {
     my ($class, %opt) = @_;
 
-    my $force = delete $opt{force_view};
+    croak('MVC::Neaf->new: no options currently supported: '.join ", ", sort keys %opt)
+        if %opt;
 
-    my $self = bless \%opt, $class;
-
-    $self->set_forced_view( $force )
-        if $force;
+    my $self = bless {}, $class;
 
     $self->set_path_defaults( { -status => 200, -view => 'JS' } );
 
@@ -217,7 +209,7 @@ sub add_route {
     $self->my_croak( "Odd number of elements in hash assignment" )
         if @_ % 2;
     my ($path, $sub, %args) = @_;
-    $self = _one_and_true($self) unless ref $self;
+    $self = _one_and_true($self);
 
     $self->my_croak( "handler must be a coderef, not ".ref $sub )
         unless UNIVERSAL::isa( $sub, "CODE" );
@@ -243,84 +235,55 @@ sub add_route {
     $self->my_croak("Public endpoint must have nonempty description")
         if $args{public} and not $args{description};
 
-    $self->_detect_duplicate( \%args );
+    my @real_method = $self->_detect_duplicate( \%args, $args{method} );
 
     # Do the work
-    my %profile;
-    $profile{parent}    = $self;
-    $profile{code}      = $sub;
-    $profile{tentative} = $args{tentative};
-    $profile{override}  = $args{override};
-    $profile{strict}    = $args{strict};
+    $args{parent}    = $self;
+    $args{code}      = $sub;
 
     # Always have regex defined to simplify routing
-    $profile{path_info_regex} = (defined $args{path_info_regex})
+    $args{path_info_regex} = (defined $args{path_info_regex})
         ? qr#^$args{path_info_regex}$#
         : qr#^$#;
 
     # Just for information
-    $profile{path}        = $path;
-    $profile{description} = $args{description};
-    $profile{public}      = $args{public} ? 1 : 0;
-    $profile{caller}      = $args{caller} || [caller(0)]; # save file,line
+    $args{public}      = $args{public} ? 1 : 0;
+    $args{caller}    ||= [caller(0)]; # save file,line
 
-    if (my $view = $args{view}) {
+    if (exists $args{view}) {
         # TODO 0.30
         carp "NEAF: route(): view argument is deprecated, use -view instead";
-        $args{default}{-view} = $view;
+        $args{default}{-view} = delete $args{view};
     };
 
     # preload view so that we can fail early
     $args{default}{-view} = $self->get_view( $args{default}{-view} )
         if $args{default}{-view};
 
-    # todo_default because some path-based defs will be mixed in later
-    $profile{default} = $args{default};
-
-    # preprocess regular expression for params
-    if ( my $reg = $args{param_regex} ) {
-        my %real_reg;
-        $self->my_croak("param_regex must be a hash of regular expressions")
-            if ref $reg ne 'HASH' or grep { !defined $reg->{$_} } keys %$reg;
-        $real_reg{$_} = qr(^$reg->{$_}$)s
-            for keys %$reg;
-        $profile{param_regex} = \%real_reg;
-    };
-
-    if ( $args{cache_ttl} ) {
-        $self->my_croak("cache_ttl must be a number")
-            unless looks_like_number($args{cache_ttl});
-        # as required by RFC
-        $args{cache_ttl} = -100000 if $args{cache_ttl} < 0;
-        $args{cache_ttl} = $year if $args{cache_ttl} > $year;
-        $profile{cache_ttl} = $args{cache_ttl};
-    };
-
     # ready, shallow copy handler & burn cache
     delete $self->{route_re};
 
-    $self->{route}{ $path }{$_} = MVC::Neaf::Route->new( %profile, method => $_ )
-        for @{ $args{method} };
+    $self->{route}{ $path }{$_} = MVC::Neaf::Route->new( %args, method => $_ )
+        for @real_method;
 
     # This is for get+post sugar
-    $self->{last_added} = \%profile;
+    $self->{last_added} = \%args;
 
     return $self;
 }; # end sub route
 
-# in: { method => [...], path => '/...', tentative => 0|1, override=> 0|1 }
-# out: none
-# spoils $method if tentative
+# in: { path => '/...', tentative => 0|1, override=> 0|1 }, \@method_list
+# out: @real_method_list
 # dies/warns if violations found
 sub _detect_duplicate {
-    my ($self, $profile) = @_;
+    my ($self, $profile, $methods) = @_;
 
     my $path = $profile->{path};
     # Handle duplicate route definitions
     my @dupe = grep {
         exists $self->{route}{$path}{$_}
         and !$self->{route}{$path}{$_}{tentative};
-    } @{ $profile->{method} };
+    } @$methods;
 
     if (@dupe) {
         my %olddef;
@@ -340,16 +303,18 @@ sub _detect_duplicate {
             carp( (ref $self)."->$caller: Overriding old handler for"
                 ." $oldpath defined $oldwhere");
         } elsif( $profile->{tentative} ) {
-            # just skip duplicate methods
+            # if we're tentative, filter out already known method/route pairs
             my %filter;
-            $filter{$_}++ for @{ $profile->{method} };
+            $filter{$_}++ for @{ $methods };
             delete $filter{$_} for @dupe;
-            $profile->{method} = [keys %filter];
+            return keys %filter;
         } else {
             croak( (ref $self)."->$caller: Attempting to set duplicate handler for"
                 ." $oldpath defined $oldwhere");
         };
     };
+
+    return @$methods;
 };
 
 # This is for get+post sugar
@@ -361,11 +326,11 @@ sub _dup_route {
     $profile ||= $self->{last_added};
     my $path = $profile->{path};
 
-    $self->_detect_duplicate($profile);
+    my @real_method = $self->_detect_duplicate($profile, [ $method ]);
 
     delete $self->{route_re};
-    $self->{route}{ $path }{$method} = MVC::Neaf::Route->new(
-        %$profile, method => $method );
+    $self->{route}{ $path }{$_} = MVC::Neaf::Route->new( %$profile, method => $_ )
+        for @real_method;
 };
 
 =head2 static()
@@ -442,7 +407,7 @@ Not need to set up one for merely testing icons/js/css, though.>
 
 sub static {
     my ($self, $path, $dir, %options) = @_;
-    $self = _one_and_true($self) unless ref $self;
+    $self = _one_and_true($self);
 
     $options{caller} ||= [caller 0];
 
@@ -492,7 +457,7 @@ This needs to be fixed in the future.
 # TODO 0.30 add_alias or something
 sub alias {
     my ($self, $new, $old) = @_;
-    $self = _one_and_true($self) unless ref $self;
+    $self = _one_and_true($self);
 
     $new = canonize_path( $new );
     $old = canonize_path( $old );
@@ -543,7 +508,7 @@ Whatever the controller returns overrides all of these.
 # TODO 0.30 rename defaults => [something]
 sub set_path_defaults {
     my $self = shift;
-    $self = _one_and_true($self) unless ref $self;
+    $self = _one_and_true($self);
 
     # Old form - path => \%hash
     # TODO 0.30 kill
@@ -653,9 +618,11 @@ $hook_phases{$_}++ for qw(pre_route
 
 sub add_hook {
     my ($self, $phase, $code, %opt) = @_;
-    $self = _one_and_true($self) unless ref $self;
+    $self = _one_and_true($self);
 
     extra_missing( \%opt, \%add_hook_args );
+    $self->my_croak( "hook must be a coderef, not ".ref $code )
+        unless UNIVERSAL::isa( $code, 'CODE' );
     $self->my_croak( "illegal phase: $phase" )
         unless $hook_phases{$phase};
 
@@ -817,7 +784,7 @@ my %view_alias = (
 );
 sub load_view {
     my ($self, $name, $obj, @param) = @_;
-    $self = _one_and_true($self) unless ref $self;
+    $self = _one_and_true($self);
 
     $self->my_croak("At least two arguments required")
         unless defined $name and defined $obj;
@@ -858,7 +825,7 @@ Returns self.
 
 sub set_forced_view {
     my ($self, $view) = @_;
-    $self = _one_and_true($self) unless ref $self;
+    $self = _one_and_true($self);
 
     delete $self->{force_view};
     return $self unless $view;
@@ -1108,7 +1075,7 @@ The engine MUST provide the following methods
 
 sub set_session_handler {
     my ($self, %opt) = @_; # TODO 0.30 use helpers when ready
-    $self = _one_and_true($self) unless ref $self;
+    $self = _one_and_true($self);
 
     my $sess = delete $opt{engine};
     my $cook = $opt{cookie} || 'neaf.session';
@@ -1185,7 +1152,7 @@ This is a synonym to C<sub { +{ status =E<gt> $status,  ... } }>.
 
 sub set_error_handler {
     my ($self, $status, $code, %where) = @_;
-    $self = _one_and_true($self) unless ref $self;
+    $self = _one_and_true($self);
 
     $status =~ /^(?:\d\d\d)$/
         or $self->my_croak( "1st argument must be an http status");
@@ -1227,7 +1194,7 @@ If it dies, only a warning is emitted.
 
 sub on_error {
     my ($self, $code) = @_;
-    $self = _one_and_true($self) unless ref $self;
+    $self = _one_and_true($self);
 
     if (defined $code) {
         ref $code eq 'CODE'
@@ -1340,7 +1307,14 @@ L<MVC::Neaf::Request::Apache2>.
 
 sub run {
     my $self = shift;
-    $self = _one_and_true($self) unless ref $self;
+    $self = _one_and_true($self);
+
+    # "Magically" load __DATA__ section from calling file
+    if ($self->{magic}) {
+        my ($file, $data) = data_fh(1);
+        $self->load_resources( $data, $file )
+            if $data;
+    };
 
     if (!defined wantarray) {
         # void context - we're being called as CGI
@@ -1354,14 +1328,11 @@ sub run {
                 unless defined $ENV{SCRIPT_NAME};
             Plack::Handler::CGI->new->run( $self->run );
         };
+        return;
     };
 
-    # "Magically" load __DATA__ section from calling file
-    if ($self->{magic}) {
-        my ($file, $data) = data_fh(1);
-        $self->load_resources( $data, $file )
-            if $data;
-    };
+    # Do postsetup after CGI/CLI execution
+    # because it's unneeded there - only one route may be needed so why bother
     $self->post_setup;
 
     return sub {
@@ -1419,7 +1390,7 @@ $run_test_allow{$_}++
     for qw( type method cookie body override secure uploads header );
 sub run_test {
     my ($self, $env, %opt) = @_;
-    $self = _one_and_true($self) unless ref $self;
+    $self = _one_and_true($self);
 
     my @extra = grep { !$run_test_allow{$_} } keys %opt;
     $self->my_croak( "Extra keys @extra" )
@@ -1516,7 +1487,7 @@ This SHOULD NOT be used by application itself.
 # TODO 0.30 Route->inspect, Route::Main->inspect
 sub get_routes {
     my ($self, $code) = @_;
-    $self = _one_and_true($self) unless ref $self;
+    $self = _one_and_true($self);
 
     $code ||= sub { $_[0] };
     scalar $self->run; # burn caches
@@ -1571,7 +1542,7 @@ are for running callbacks, handling corner cases, and substituting sane defaults
 
 sub handle_request {
     my ($self, $req) = @_;
-    $self = _one_and_true($self) unless ref $self;
+    $self = _one_and_true($self);
 
     my $data = eval {
         my $hash = $self->dispatch_logic( $req, '', $req->path );
@@ -1617,7 +1588,7 @@ If L</set_forced_view> was called, return its argument instead.
 
 sub get_view {
     my ($self, $view, $lazy) = @_;
-    $self = _one_and_true($self) unless ref $self;
+    $self = _one_and_true($self);
 
     # An object/code means controller knows better
     return $view
@@ -1860,7 +1831,7 @@ sub route {
 
 This module is part of L<MVC::Neaf> suite.
 
-Copyright 2016-2018 Konstantin S. Uvarin C<khedin@cpan.org>.
+Copyright 2016-2019 Konstantin S. Uvarin C<khedin@cpan.org>.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
