@@ -2,7 +2,7 @@ package MVC::Neaf::Route::PreRoute;
 
 use strict;
 use warnings;
-our $VERSION = '0.2603_03';
+our $VERSION = '0.2701_02';
 
 =head1 NAME
 
@@ -35,11 +35,23 @@ use parent qw(MVC::Neaf::Route);
 my $nobody_home = sub { die 404 };
 sub new {
     my $class = shift;
-    my $self = $class->SUPER::new(
-        where => '[in pre_route]', path => '/', code => $nobody_home, @_ );
 
-    $self->post_setup();
-    $self->{path} = "[pre_route]";
+    # Not using SUPER::new because MVC::Neaf::Route requires a parent
+    my $self = bless {
+        where   => '[in pre_route]',
+        path    => '/',
+        code    => $nobody_home,
+        default => {},
+        hooks   => {},
+        helpers => {},
+        @_
+    }, $class;
+
+    $self->post_setup()
+        if $self->{parent};
+
+    # Probably a bad idea. How to visually separate missing path in logs?
+    $self->{path} = '[pre_route]';
     $self;
 };
 
@@ -52,6 +64,8 @@ sub new {
 
 =item * path = C<'[pre_route]'>
 
+May change to C</> in the future.
+
 =item * code = C<die 404;>
 
 =item * where = C<'[pre_route]'>
@@ -62,12 +76,11 @@ Do not rely on these values.
 
 =cut
 
-
 =head1 LICENSE AND COPYRIGHT
 
 This module is part of L<MVC::Neaf> suite.
 
-Copyright 2016-2018 Konstantin S. Uvarin C<khedin@cpan.org>.
+Copyright 2016-2019 Konstantin S. Uvarin C<khedin@cpan.org>.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
